@@ -247,7 +247,6 @@ static CORBA_char *
 bonobo_control_frame_get_remote_window_id (BonoboControlFrame *frame,
 					   CORBA_Environment  *ev)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	CORBA_char  *retval;
 	char        *cookie;
 	int          screen;
@@ -263,10 +262,6 @@ bonobo_control_frame_get_remote_window_id (BonoboControlFrame *frame,
 	g_free (cookie);
 
 	return retval;
-#else
-	return Bonobo_Control_getWindowId (
-				frame->priv->control, "", ev);
-#endif /* HAVE_GTK_MULTIHEAD */
 }
 
 void
@@ -311,10 +306,12 @@ bonobo_control_frame_get_remote_window (BonoboControlFrame *frame,
 		CORBA_free (id);
 
 		{
+			GdkDisplay *display = gtk_widget_get_display (frame->priv->socket);
 			gpointer user_data = NULL;
-			if (gdk_window_lookup (xid)) {
-				gdk_window_get_user_data (gdk_window_lookup (xid),
-							  &user_data);
+			if (gdk_window_lookup_for_display (display, xid)) {
+				gdk_window_get_user_data
+					(gdk_window_lookup_for_display (display, xid),
+					 &user_data);
 				plug = user_data;
 			}
 		}
@@ -482,7 +479,7 @@ bonobo_control_frame_init (BonoboObject *object)
 BONOBO_TYPE_FUNC_FULL (BonoboControlFrame, 
 		       Bonobo_ControlFrame,
 		       PARENT_TYPE,
-		       bonobo_control_frame);
+		       bonobo_control_frame)
 
 /**
  * bonobo_control_frame_control_activate:
